==> dolt-0.30.2.tar.gz: dolt-0.30.2/go/store/nbs/benchmarks/gen/rolling_value_hasher.go <==
// Copyright 2019 Dolthub, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// This file incorporates work covered by the following copyright and
// permission notice:
//
// Copyright 2016 Attic Labs, Inc. All rights reserved.
// Licensed under the Apache License, version 2.0:
// http://www.apache.org/licenses/LICENSE-2.0

package gen

import "github.com/kch42/buzhash"

const (
	chunkPattern = uint32(1<<12 - 1) // Avg Chunk Size of 4k

	// The window size to use for computing the rolling hash. This is way more than necessary assuming random data (two bytes would be sufficient with a target chunk size of 4k). The benefit of a larger window is it allows for better distribution on input with lower entropy. At a target chunk size of 4k, any given byte changing has roughly a 1.5% chance of affecting an existing boundary, which seems like an acceptable trade-off.
	chunkWindow = uint32(64)
)

type rollingValueHasher struct {
	bz *buzhash.BuzHash
}

func newRollingValueHasher() *rollingValueHasher {
	return &rollingValueHasher{buzhash.NewBuzHash(chunkWindow)}
}

func (rv *rollingValueHasher) HashByte(b byte) bool {
	rv.bz.HashByte(b)
	return rv.bz.Sum32()&chunkPattern == chunkPattern
}

==> dolt-0.40.11.tar.gz: dolt-0.40.11/go/store/nbs/benchmarks/gen/rolling_value_hasher.go <==
// Copyright 2019 Dolthub, Inc.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// This file incorporates work covered by the following copyright and
// permission notice:
//
// Copyright 2016 Attic Labs, Inc. All rights reserved.
// Licensed under the Apache License, version 2.0:
// http://www.apache.org/licenses/LICENSE-2.0

package gen

import "github.com/silvasur/buzhash"

const (
	chunkPattern = uint32(1<<12 - 1) // Avg Chunk Size of 4k

	// The window size to use for computing the rolling hash. This is way more than necessary assuming random data (two bytes would be sufficient with a target chunk size of 4k). The benefit of a larger window is it allows for better distribution on input with lower entropy. At a target chunk size of 4k, any given byte changing has roughly a 1.5% chance of affecting an existing boundary, which seems like an acceptable trade-off.
	chunkWindow = uint32(64)
)

type rollingValueHasher struct {
	bz *buzhash.BuzHash
}

func newRollingValueHasher() *rollingValueHasher {
	return &rollingValueHasher{buzhash.NewBuzHash(chunkWindow)}
}

func (rv *rollingValueHasher) HashByte(b byte) bool {
	rv.bz.HashByte(b)
	return rv.bz.Sum32()&chunkPattern == chunkPattern
}
